@@ -2,6 +2,7 @@
 import json
 import os
 import platform
+import random
 import re
 import subprocess
 import sys
@@ -10,7 +11,6 @@ from pathlib import Path
 from typing import Union
 
 import requests
-from fake_useragent import UserAgent
 from lxml import etree
 
 requests.packages.urllib3.disable_warnings()
@@ -159,9 +159,6 @@ def __handle(path, dict_sys, browser_type, version, browser_version):
     file_url = __func_select(browser_type, dict_sys, version)
     if not file_url:
         return ''
-    # 删除冗余文件
-    sys_type = dict_sys['os'] + '64' if dict_sys['is_64'] else dict_sys['os'] + '32'
-    __clear_old_version(dir_path, sys_type)
     # 根据下载连接,下载解压文件
     result = __save_file(path_driver, file_url)
     # 返回路径
@@ -449,7 +446,7 @@ def __func_select(driver_type, dict_sys, version) -> str:
         if file_url:
             print('已获取下载链接: ', file_url)
             break
-        print(f'源: {site[0]} 获取失败')
+        print(f'下载源: {site[0]} 获取失败')
     if not file_url:
         print(f'xx 错误,未获取到下载链接,请检查版本号是否正确{sites}')
     return file_url
@@ -523,7 +520,7 @@ def __by_npmmirror_json(url, dict_sys, version) -> str:
     """
     # 获取所有版本  (网页返回的是json)
     s = __session()
-    lst_data = json.loads(s.get(url).text)
+    lst_data = json.loads(s.get(url,timeout=).text)
     d_version = {}
     for dt in lst_data:
         if '/' not in dt['name']:  # 剔除非目录的
@@ -674,7 +671,9 @@ def __check_file(path, dict_sys, browser_type, version) -> Path:
         for f in dir_file.glob('*.*'):
             if f.stem == dict_sys['file_name']:
                 return f
-
+    # 删除冗余文件
+    sys_type = dict_sys['os'] + '64' if dict_sys['is_64'] else dict_sys['os'] + '32'
+    __clear_old_version(dir_path, sys_type)
     dir_file.mkdir(parents=True, exist_ok=True)  # 创建对应目录
     return dir_file
 
@@ -752,9 +751,34 @@ def __session() -> requests.session():
     session 关ssl验证, 加headers
     :return:
     """
-    headers = {'User-Agent': UserAgent().random}
+    # 固定headers列表,减少依赖包
+    lst_headers = [
+                  "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36",
+                  "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:106.0) Gecko/20100101 Firefox/106.0",
+                  "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36 Edg/91.0.100.0",
+                  "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:106.0) Gecko/20100101 Firefox/106.0",
+                  "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/605.1.15 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/604.1 Edg/91.0.100.0",
+                  "Mozilla/5.0 (iPhone; CPU iPhone OS 12_3_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.1.1 EdgiOS/44.5.0.10 Mobile/15E148 Safari/604.1",
+                  "Mozilla/5.0 (iPad; CPU OS 12_3_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0 EdgiOS/44.5.2 Mobile/15E148 Safari/605.1.15",
+                  "Mozilla/5.0 (Linux; Android 8.1.0; Pixel Build/OPM4.171019.021.D1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/65.0.3325.109 Mobile Safari/537.36 EdgA/42.0.0.2057",
+                  "Mozilla/5.0 (Linux; Android 6.0.1; Nexus 7 Build/MOB30X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/65.0.3325.109 Safari/537.36 EdgA/42.0.0.2057",
+                  "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.102 Safari/537.36 Edge/18.19042",
+                  "Mozilla/5.0 (Windows NT 10.0; Win64; x64; Xbox; Xbox One) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.102 Safari/537.36 Edge/18.19041",
+                  "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36 OPR/65.0.3467.48",
+                  "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36 OPR/65.0.3467.48",
+                  "Opera/9.80 (Macintosh; Intel Mac OS X 10.9.1) Presto/2.12.388 Version/12.16",
+                  "Opera/9.80 (Windows NT 6.1) Presto/2.12.388 Version/12.16",
+                  "Opera/12.02 (Android 4.1; Linux; Opera Mobi/ADR-1111101157; U; en-US) Presto/2.9.201 Version/12.02",
+                  "Opera/9.80 (iPhone; Opera Mini/8.0.0/34.2336; U; en) Presto/2.8.119 Version/11.10",
+                  "Mozilla/5.0 (iPad; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1",
+                  "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1",
+                  "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Safari/605.1.15",
+                  "Mozilla/5.0 (Linux; U; Android 8.1.0; en-US; Nexus 6P Build/OPM7.181205.001) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/57.0.2987.108 UCBrowser/12.11.1.1197 Mobile Safari/537.36",
+                  "Mozilla/5.0 (iPhone; CPU iPhone OS 12_1 like Mac OS X; zh-CN) AppleWebKit/537.51.1 (KHTML, like Gecko) Mobile/16B92 UCBrowser/12.1.7.1109 Mobile AliApp(TUnionSDK/0.1.20.3)",]
+    headers = {'User-Agent': random.choice(lst_headers) }
     s = requests.session()
     s.verify = False
     s.headers.update(headers)
     s.trust_env = False  # 禁用代理
     return s
+
